import { Box, Button, Stack, Typography } from '@mui/material';
import {
    useSeekaConverge
} from '@seeka-labs/converge-react';

export const ExampleConsent = () => {
    const converge = useSeekaConverge();

    const onAllowMarketing = async (type: 'email' | 'sms') => {
        await converge?.identity.mergeProfile({
            consent: {
                marketing: {
                    [type]: {
                        consentGrantedAt: new Date(),
                        consentGrantedSourceName: 'react-app-testing',
                    }
                }
            }
        })

        await converge?.identity.syncIdentity('consent-set');
    }

    const onDisallowMarketing = async (type: 'email' | 'sms') => {
        await converge?.identity.mergeProfile({
            consent: {
                marketing: {
                    [type]: {
                        consentNotGrantedAt: new Date(),
                        consentNotGrantedSourceName: 'react-app-testing',
                    }
                }
            }
        })

        await converge?.identity.syncIdentity('consent-set');
    }

    return (
        <Stack gap={4}>
            <Box>
                <Typography variant='h6'>Consent - allow</Typography>
                <Stack gap={2} direction='row'>
                    <Button variant='outlined' color='primary' onClick={() => onAllowMarketing('email')}>Allow email</Button>
                    <Button variant='outlined' color='primary' onClick={() => onAllowMarketing('sms')}>Allow SMS</Button>
                </Stack>
            </Box>
            <Box>
                <Typography variant='h6'>Consent - disallow</Typography>
                <Stack gap={2} direction='row'>
                    <Button variant='outlined' color='primary' onClick={() => onDisallowMarketing('email')}>Disallow email</Button>
                    <Button variant='outlined' color='primary' onClick={() => onDisallowMarketing('sms')}>Disallow SMS</Button>
                </Stack>
            </Box>
        </Stack>
    )
}