import * as React from 'react';

import { Box, Divider, Stack, Typography } from '@mui/material';
import Button from '@mui/material/Button';
import {
    CommerceActivityTrackingEventMetadata, CommerceActivityTrackingEventProductMetadata
} from '@seeka-labs/converge';
import { useSeekaConverge } from '@seeka-labs/converge-react';

export const product = (index: number, currencyCode?: string): CommerceActivityTrackingEventProductMetadata => {
    return {
        productIdentifier: `product-${index}`,
        productName: `Product ${index}`,
        unitPrice: 100 * index,
        quantity: index,
        categoryName: `category-${index}`,
        brandName: `brand-${index}`,
        variantIdentifier: `variant-${index}`,
        currencyCode: currencyCode,
    }
}

export const order = (): CommerceActivityTrackingEventMetadata => {
    return {
        products: [
            product(1),
            product(2)
        ],
        orderNumber: 'order-123',
        currencyCode: 'USD',
    }
}

const salesforceLeadStageNames = [
    '1. Open - Not Contacted',
    '2. Introductory Call',
    '3. Qualification',
    '4. Meeting & Follow up',
    '5. Databased',
    '5. Disqualified',
    'Converted',
]

export const ExampleEventTracker = () => {
    const converge = useSeekaConverge();

    const onCustom = () => {
        converge?.track.custom('MyCustomEventName', {
            contentName: 'a custom content name',
            custom: {
                customProperty1: 'My value'
            }
        });
    }

    const onOrder = () => {
        converge?.track.order(order());
    }

    const onViewProductUSD = () => {
        converge?.track.viewProduct(product(1, 'USD'));
    }

    const onViewProductDefaultCurrencyCode = () => {
        converge?.track.viewProduct(product(2));
    }

    const onLead = () => {
        converge?.track.lead({
            sourceContentName: 'Lead magnet form',
        })
    }
    const onSalesForceLead = (stageName: string) => {
        converge?.track.custom('SalesforceLeadUpdated', {
            custom: {
                salesforceLeadId: '12345678',
                salesforceLeadStageName: stageName,
                value: '14520',
                currencyCode: 'AUD',
            }
        })
    }

    return (
        <Stack gap={4} direction='column' divider={<Divider component={'div'} />}>
            <Box>
                <Typography variant='h6' gutterBottom>Standard</Typography>
                <Stack gap={2} direction='row'>
                    <Button variant='outlined' onClick={() => onOrder()}>Order / purchase</Button>
                    <Button variant='outlined' onClick={() => onViewProductDefaultCurrencyCode()}>Default currency - View product / view content</Button>
                    <Button variant='outlined' onClick={() => onViewProductUSD()}>USD - View product / view content</Button>
                    <Button variant='outlined' onClick={() => onLead()}>Lead</Button>
                    <Button variant='outlined' onClick={() => onCustom()}>Custom</Button>
                </Stack>
            </Box>
            <Box>
                <Typography variant='h6' gutterBottom>Salesforce lead stages</Typography>
                <Stack gap={2} direction='column'>
                    {
                        salesforceLeadStageNames.map((stageName, index) => (
                            <Button variant='outlined' size='small' key={index} onClick={() => onSalesForceLead(stageName)}>{stageName}</Button>
                        ))
                    }
                </Stack>
            </Box>
        </Stack>
    )
}