import * as React from 'react';

import Box from '@mui/material/Box';
import Tab from '@mui/material/Tab';
import Tabs from '@mui/material/Tabs';

import { ExampleConsent } from './consent';
import { ExampleCrossDomainLink } from './crossDomainLink';
import { ExampleEventTracker } from './eventTracker';
import { ExampleIdentity } from './identity';

interface TabPanelProps {
  children?: React.ReactNode;
  index: number;
  value: number;
}

function CustomTabPanel(props: TabPanelProps) {
  const { children, value, index, ...other } = props;

  return (
    <div
      role="tabpanel"
      hidden={value !== index}
      id={`simple-tabpanel-${index}`}
      aria-labelledby={`simple-tab-${index}`}
      {...other}
    >
      {value === index && (
        <Box sx={{ p: 3 }}>
          {children}
        </Box>
      )}
    </div>
  );
}

function a11yProps(index: number) {
  return {
    id: `simple-tab-${index}`,
    'aria-controls': `simple-tabpanel-${index}`,
  };
}

export function ExampleTabs() {
  const [value, setValue] = React.useState(0);

  const handleChange = (event: React.SyntheticEvent, newValue: number) => {
    setValue(newValue);
  };

  return (
    <Box>
      <Box>
        <Box sx={{ borderBottom: 1, borderColor: 'divider' }}>
          <Tabs value={value} onChange={handleChange} aria-label="basic tabs example">
            <Tab label="Event tracking" {...a11yProps(0)} />
            <Tab label="Identity" {...a11yProps(1)} />
            <Tab label="Consent" {...a11yProps(2)} />
            <Tab label="Cross domain links" {...a11yProps(3)} />
          </Tabs>
        </Box>

        <CustomTabPanel value={value} index={0}>
          <ExampleEventTracker />
        </CustomTabPanel>

        <CustomTabPanel value={value} index={1}>
          <ExampleIdentity />
        </CustomTabPanel>

        <CustomTabPanel value={value} index={2}>
          <ExampleConsent />
        </CustomTabPanel>

        <CustomTabPanel value={value} index={3}>
          <ExampleCrossDomainLink />
        </CustomTabPanel>
      </Box>
    </Box>
  );
}